@@ -1,12 +1,12 @@
 #!/usr/bin/python3
 
 import email.utils
-from lintian_brush.changelog import ChangelogUpdater
+from debmutate.changelog import ChangelogEditor
 
 versions = []
 
 
-with ChangelogUpdater() as updater:
+with ChangelogEditor() as updater:
     for block in updater.changelog:
         try:
             dt = email.utils.parsedate_to_datetime(block.date)
@@ -22,7 +22,10 @@ with ChangelogUpdater() as updater:
             block.date = newdate
             versions.append(block.version)
 
-
-print('Fix day-of-week for changelog entries %s.'
-      % ', '.join([str(v) for v in versions]))
+if len(versions) == 1:
+    print('Fix day-of-week for changelog entry %s.'
+          % ', '.join([str(v) for v in versions]))
+else:
+    print('Fix day-of-week for changelog entries %s.'
+          % ', '.join([str(v) for v in versions]))
 print('Fixed-Lintian-Tags: debian-changelog-has-wrong-day-of-week')
