@@ -3,8 +3,9 @@
 
 from lintian_brush.rules import (
     dh_invoke_drop_with,
-    update_rules,
+    RulesEditor,
     )
+from lintian_brush.patches import rules_find_patches_directory
 
 
 def drop_quilt_with(line, target):
@@ -14,7 +15,10 @@ def drop_quilt_with(line, target):
 try:
     with open('debian/source/format', 'r') as f:
         if f.read().strip() == '3.0 (quilt)':
-            update_rules(drop_quilt_with)
+            with RulesEditor() as updater:
+                if rules_find_patches_directory(
+                        updater.makefile) in ('debian/patches', None):
+                    updater.legacy_update(command_line_cb=drop_quilt_with)
 except FileNotFoundError:
     pass
 
