@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 
-from lintian_brush.control import (
-    ControlUpdater,
+from debmutate.control import (
+    ControlEditor,
     get_relation,
     drop_dependency,
     add_dependency,
@@ -9,7 +9,7 @@ from lintian_brush.control import (
 from lintian_brush.fixer import report_result
 
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     try:
         get_relation(
             updater.source.get('Build-Depends-Indep', ''),
