@@ -1,8 +1,8 @@
 #!/usr/bin/python3
 
-from lintian_brush.changelog import ChangelogUpdater
-from lintian_brush.control import (
-    ControlUpdater,
+from debmutate.changelog import ChangelogEditor
+from debmutate.control import (
+    ControlEditor,
     )
 from lintian_brush.fixer import report_result
 
@@ -13,12 +13,12 @@ TEAM_UPLOAD_LINE = '  * Team upload.'
 uploader_emails = []
 
 
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     for entry in updater.source.get('Uploaders', '').split(','):
         uploader_emails.append(parseaddr(entry)[1])
 
 
-with ChangelogUpdater() as updater:
+with ChangelogEditor() as updater:
     last_change = updater.changelog[0]
     if last_change.distributions != 'UNRELEASED':
         sys.exit(0)
