@@ -52,7 +52,7 @@ from debian.deb822 import Deb822
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 72)
+__version__ = (0, 74)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'confident', 'likely', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -808,6 +808,12 @@ class ManyResult(object):
         self.failed_fixers = {}
         self.formatting_unpreservable = {}
 
+    def minimum_success_certainty(self) -> str:
+        """Return the minimum certainty of any successfully made change."""
+        return min_certainty(
+            [r.certainty for r, unused_summary in self.success
+             if r.certainty is not None])
+
     def __tuple__(self):
         return (self.success, self.failed_fixers)
 
