@@ -21,7 +21,6 @@ import contextlib
 from email.message import Message
 from io import BytesIO
 import os
-import tempfile
 
 from breezy.diff import show_diff_trees
 from breezy import osutils
@@ -29,8 +28,7 @@ from breezy.commit import filter_excluded
 import breezy.bzr  # noqa: F401
 import breezy.git  # noqa: F401
 from breezy.errors import NotBranchError, NoSuchFile
-from breezy.patches import parse_patches
-from breezy.patch import write_to_cmd
+from breezy.patches import parse_patches, apply_patches
 
 from debian.changelog import Changelog
 
@@ -93,44 +91,6 @@ def find_patches_branch(tree):
     return None
 
 
-# Copied from lp:~jelmer/brz/transform-patches
-def apply_patches(tt, patches, prefix=1):
-    """Apply patches to a TreeTransform.
-
-    :param tt: TreeTransform instance
-    :param patches: List of patches
-    """
-    def strip_prefix(p):
-        return '/'.join(p.split('/')[prefix:])
-
-    from breezy.bzr.generate_ids import gen_file_id
-    # TODO(jelmer): Extract and set mode
-    for patch in patches:
-        if patch.oldname == b'/dev/null':
-            trans_id = None
-            orig_contents = b''
-        else:
-            oldname = strip_prefix(patch.oldname.decode())
-            trans_id = tt.trans_id_tree_path(oldname)
-            orig_contents = tt._tree.get_file_text(oldname)
-            tt.delete_contents(trans_id)
-
-        if patch.newname != b'/dev/null':
-            new_contents = iter_patched_from_hunks(
-                orig_contents.splitlines(True), patch.hunks)
-            if trans_id is None:
-                newname = strip_prefix(patch.newname.decode())
-                parts = os.path.split(newname)
-                trans_id = tt.root
-                for part in parts[1:-1]:
-                    trans_id = tt.new_directory(part, trans_id)
-                tt.new_file(
-                    parts[-1], trans_id, new_contents,
-                    file_id=gen_file_id(newname))
-            else:
-                tt.create_file(new_contents, trans_id)
-
-
 class AppliedPatches(object):
     """Context that provides access to a tree with patches applied.
     """
@@ -156,6 +116,7 @@ class AppliedPatches(object):
         return False
 
 
+# TODO(jelmer): Use debmutate version
 def read_quilt_series(f):
     for line in f:
         if line.startswith(b'#'):
@@ -299,40 +260,13 @@ def tree_non_patches_changes(tree, patches_directory):
         for change in filter_excluded(
                 patches_tree.iter_changes(upstream_patches_tree),
                 exclude=['debian']):
-            try:
-                path = change.path[1]
-            except AttributeError:  # breezy < 3.1
-                path = change[1][1]
+            path = change.path[1]
             if path == '':
                 continue
             yield change
 
 
-# Copied from lp:~jelmer/brz/patch-api
-def iter_patched_from_hunks(orig_lines, hunks):
-    """Iterate through a series of lines with a patch applied.
-    This handles a single file, and does exact, not fuzzy patching.
-
-    :param orig_lines: The unpatched lines.
-    :param hunks: An iterable of Hunk instances.
-
-    This is different from breezy.patches in that it invokes the patch
-    command.
-    """
-    with tempfile.NamedTemporaryFile() as f:
-        f.writelines(orig_lines)
-        f.flush()
-        # TODO(jelmer): Stream patch contents to command, rather than
-        # serializing the entire patch upfront.
-        serialized = b''.join([hunk.as_bytes() for hunk in hunks])
-        args = ["patch", "-f", "-s", "--posix", "--binary",
-                "-o", "-", f.name, "-r", "-"]
-        stdout, stderr, status = write_to_cmd(args, serialized)
-    if status == 0:
-        return [stdout]
-    raise Exception(stderr)
-
-
+# TODO(jelmer): Use debmutate version
 def find_common_patch_suffix(names, default='.patch'):
     """Find the common prefix to use for patches.
 
@@ -384,6 +318,7 @@ def add_patch(tree, patches_directory, name, contents, header=None):
 
     # TODO(jelmer): Write to patches branch if applicable
 
+    # TODO(jelmer): Use debmutate SeriesEditor
     series_path = os.path.join(patches_directory, 'series')
     with open(tree.abspath(series_path, 'a')) as f:
         f.write('%s\n' % patchname)
