@@ -21,14 +21,17 @@ import json
 import os
 import re
 import socket
-import subprocess
-import tempfile
 import urllib.error
 from urllib.parse import quote, urlparse, urlunparse, urljoin, parse_qs
 from warnings import warn
 
 from debian.deb822 import Deb822
 
+from debmutate.vcs import (
+    split_vcs_url,
+    unsplit_vcs_url,
+    )
+
 from lintian_brush import (
     USER_AGENT,
     DEFAULT_URLLIB_TIMEOUT,
@@ -42,8 +45,6 @@ from lintian_brush.vcs import (
     plausible_url as plausible_vcs_url,
     sanitize_url as sanitize_vcs_url,
     is_gitlab_site,
-    split_vcs_url,
-    unsplit_vcs_url,
     )
 from urllib.request import urlopen, Request
 
@@ -198,6 +199,8 @@ def guess_repo_from_url(url, net_access=False):
         parts = parsed_url.path.split('/')
         if 'tags' in parts:
             parts = parts[:parts.index('tags')]
+        if parts[-1] == '-':
+            parts.pop(-1)
         return urlunparse(
             parsed_url._replace(path='/'.join(parts), query=''))
     if parsed_url.hostname == 'git.php.net':
@@ -279,7 +282,7 @@ def guess_from_debian_rules(path, trust_package):
 
 
 def guess_from_debian_watch(path, trust_package):
-    from ..watch import (
+    from debmutate.watch import (
         parse_watch_file,
         MissingVersion,
         )
@@ -367,41 +370,38 @@ def guess_from_pkg_info(path, trust_package):
 def guess_from_setup_py(path, trust_package):
     if not trust_package:
         return
-    args = [os.path.abspath(path), 'dist_info']
-    with open(path, 'rb') as f:
-        has_shebang = f.readline().startswith(b'#!')
-    is_executable = (os.stat(path).st_mode & 0o100 != 0)
-    if not has_shebang or not is_executable:
-        # TODO(jelmer): Why python3 and not e.g. python?
-        args.insert(0, 'python3')
-
-    with tempfile.TemporaryDirectory() as td:
-        try:
-            subprocess.call(
-                args, cwd=td, stderr=subprocess.PIPE,
-                stdout=subprocess.PIPE)
-        except FileNotFoundError:
-            pass
-        except subprocess.CalledProcessError:
-            if args[0] == 'python3':
-                args[0] = 'python2'
-            else:
-                raise
-            subprocess.call(
-                args, cwd=td, stderr=subprocess.PIPE,
-                stdout=subprocess.PIPE)
-        try:
-            [result_entry] = os.listdir(td)
-        except ValueError:
-            return
-        if result_entry.endswith('.egg-info'):
-            yield from guess_from_pkg_info(
-                os.path.join(td, result_entry, 'PKG-INFO'),
-                trust_package)
-        if result_entry.endswith('.dist-info'):
-            return read_python_pkg_info(
-                os.path.join(td, result_entry, 'METADATA'),
-                trust_package)
+    from distutils.core import run_setup
+    result = run_setup(os.path.abspath(path), stop_after="init")
+    if result.get_name() not in (None, '', 'UNKNOWN'):
+        yield UpstreamDatum('Name', result.get_name(), 'certain')
+    if result.get_version() not in (None, '', 'UNKNOWN'):
+        yield UpstreamDatum('X-Version', result.get_version(), 'certain')
+    if result.get_url() not in (None, '', 'UNKNOWN'):
+        repo = guess_repo_from_url(result.get_url())
+        if repo:
+            yield UpstreamDatum(
+                'Repository', sanitize_vcs_url(repo), 'likely')
+    if result.get_download_url() not in (None, '', 'UNKNOWN'):
+        yield UpstreamDatum(
+            'X-Download', result.get_download_url(), 'likely')
+    if result.get_contact() not in (None, '', 'UNKNOWN'):
+        contact = result.get_contact()
+        if result.get_contact_email() not in (None, '', 'UNKNOWN'):
+            contact += " <%s>" % result.get_contact_email()
+        yield UpstreamDatum('Contact', contact, 'likely')
+    if result.get_description() not in (None, '', 'UNKNOWN'):
+        yield UpstreamDatum('X-Summary', result.get_description(), 'certain')
+    if (result.metadata.long_description_content_type in (None, 'text/plain')
+            and result.metadata.long_description not in (None, '', 'UNKNOWN')):
+        yield UpstreamDatum(
+            'X-Description', result.metadata.long_description, 'possible')
+    for url_type, url in result.metadata.project_urls.items():
+        if url_type in ('GitHub', 'Repository', 'Source Code'):
+            yield UpstreamDatum(
+                'Repository', sanitize_vcs_url(url), 'certain')
+        if url_type in ('Bug Tracker', ):
+            yield UpstreamDatum(
+                'Bug-Database', url, 'certain')
 
 
 def guess_from_package_json(path, trust_package):
@@ -572,14 +572,15 @@ def guess_from_readme(path, trust_package):
                         url = args[0]
                     if plausible_vcs_url(url):
                         urls.append(sanitize_vcs_url(url))
+                project_re = b'([^/]+)/([^/?.()">\\s]*[^-/?.()">\\s])'
                 for m in re.finditer(
-                        b'https://travis-ci.org/([^/]+)/([^/?.()>]+)', line):
+                        b'https://travis-ci.org/' + project_re, line):
                     yield UpstreamDatum(
                         'Repository', 'https://github.com/%s/%s' % (
                             m.group(1).decode(), m.group(2).decode().rstrip()),
                         'possible')
                 for m in re.finditer(
-                        b'https://coveralls.io/r/([^/]+)/([^/?.]+)', line):
+                        b'https://coveralls.io/r/' + project_re, line):
                     yield UpstreamDatum(
                         'Repository', 'https://github.com/%s/%s' % (
                             m.group(1).decode(), m.group(2).decode().rstrip()),
@@ -590,14 +591,14 @@ def guess_from_readme(path, trust_package):
                         'Bug-Database',
                         m.group(0).decode().rstrip(), 'possible')
                 for m in re.finditer(
-                        b'https://github.com/([^/]+)/([^/\\s()>]+)(.git)?',
+                        b'https://github.com/' + project_re + b'(.git)?',
                         line):
                     yield UpstreamDatum(
                         'Repository',
                         m.group(0).rstrip(b'.').decode().rstrip(),
                         'possible')
                 m = re.fullmatch(
-                    b'https://github.com/([^/]+)/([^/?.()>]+)', line)
+                    b'https://github.com/' + project_re, line)
                 if m:
                     yield UpstreamDatum(
                         'Repository',
@@ -608,7 +609,7 @@ def guess_from_readme(path, trust_package):
                         'Repository',
                         line.strip().rstrip(b'.').decode(), 'possible')
                 for m in re.finditer(
-                        b'https://([^/]+)/([^\\s()]+)', line):
+                        b'https://([^/]+)/([^\\s()"]+)', line):
                     if is_gitlab_site(m.group(1).decode()):
                         yield UpstreamDatum(
                             'Repository',
@@ -837,6 +838,9 @@ def guess_from_configure(path, trust_package=False):
             if key == b'PACKAGE_NAME':
                 yield UpstreamDatum(
                     'Name', value.decode(), 'certain', './configure')
+            elif key == b'PACKAGE_VERSION':
+                yield UpstreamDatum(
+                    'X-Version', value.decode(), 'certain', './configure')
             elif key == b'PACKAGE_BUGREPORT':
                 if value in (b'BUG-REPORT-ADDRESS', ):
                     certainty = 'invalid'
@@ -970,7 +974,12 @@ def guess_from_pom_xml(path, trust_package=False):
     for scm_tag in root.findall('scm'):
         url_tag = scm_tag.find('url')
         if url_tag is not None:
-            yield UpstreamDatum('Repository-Browse', url_tag.text, 'certain')
+            if (url_tag.text.startswith('scm:') and
+                    url_tag.text.count(':') >= 3):
+                url = url_tag.text.split(':', 2)[2]
+            else:
+                url = url_tag.text
+            yield UpstreamDatum('Repository-Browse', url, 'certain')
         connection_tag = scm_tag.find('connection')
         if connection_tag is not None:
             connection = connection_tag.text
@@ -1155,7 +1164,11 @@ def _possible_fields_missing(upstream_metadata, fields, field_certainty):
 
 
 def _sf_git_extract_url(page):
-    from bs4 import BeautifulSoup
+    try:
+        from bs4 import BeautifulSoup
+    except ModuleNotFoundError:
+        warn('Not scanning sourceforge page, since python3-bs4 is missing')
+        return None
     bs = BeautifulSoup(page, features='lxml')
     el = bs.find(id='access_url')
     if not el:
@@ -1815,7 +1828,11 @@ def guess_from_pecl_url(url):
     except socket.timeout:
         warn('timeout contacting pecl, ignoring: %s' % url)
         return
-    from bs4 import BeautifulSoup
+    try:
+        from bs4 import BeautifulSoup
+    except ModuleNotFoundError:
+        warn('bs4 missing so unable to scan pecl page, ignoring %s' % url)
+        return
     bs = BeautifulSoup(f.read(), features='lxml')
     tag = bs.find('a', text='Browse Source')
     if tag is not None:
